/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.common.osgi;

import java.util.ArrayList;
import java.util.List;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class DescriptorListBuilder{
    private List<ServiceRequirementDescriptor> myDependencies;
    
    public DescriptorListBuilder(){
        myDependencies = new ArrayList<ServiceRequirementDescriptor>();
    }
    
    public DescriptorListBuilder addId(
            String localFactoryDependencyId, Class clazz, 
            String idPropertyName, String serviceId){
        return addId(localFactoryDependencyId, clazz, 
                idPropertyName, serviceId, null);
    }
    
    public DescriptorListBuilder addId(
            String localFactoryDependencyId, Class clazz, 
            String idPropertyName, String serviceId, String filter){
        myDependencies.add(
                ServiceRequirementDescriptor.buildForServiceId(
                        localFactoryDependencyId, clazz, 
                        idPropertyName, serviceId, filter));
        return this;
    }
    
    public DescriptorListBuilder add(
            String localFactoryDependencyId, Class clazz, String filter){
        myDependencies.add(
                new ServiceRequirementDescriptor(
                        localFactoryDependencyId, clazz, filter));
        return this;
    }
    
    public List<ServiceRequirementDescriptor> getDescriptors(){
        return myDependencies;
    }
}
