/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.common.osgi;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class ServiceRequirementDescriptor {
    private String myRequirementId;
    private Class myDependencyClass;
    private String myDependencyFilter;
    
    public static ServiceRequirementDescriptor buildForServiceId(
            String localId, Class clazz, 
            String idPropertyName, String serviceId, String filter){
        String idFilter = 
                OSGiUtils.createIdFilter(idPropertyName, serviceId, filter);
        return new ServiceRequirementDescriptor(
                localId, clazz, idFilter);
    }
    
    public ServiceRequirementDescriptor(String requirementId, 
            Class clazz, String filter){
        if(requirementId == null || clazz == null){
            throw new NullPointerException();
        }
        myRequirementId = requirementId;
        myDependencyClass = clazz;
        myDependencyFilter = filter;
    }

    public String getRequirementId(){
        return myRequirementId;
    }

    public Class getServiceClass(){
        return myDependencyClass;
    }

    public String getServiceFilter(){
        return myDependencyFilter;
    }
}
